@@ -15,7 +15,7 @@ use Lemonldap::NG::Common::Apache::Session::Serialize::JSON;
 use Lemonldap::NG::Common::Apache::Session::Store;
 use Lemonldap::NG::Common::Apache::Session::Lock;
 
-our $VERSION = '1.9.4';
+our $VERSION = '1.9.5';
 
 sub _load {
     my ( $backend, $func ) = @_;
@@ -43,6 +43,10 @@ sub populate {
           \&Lemonldap::NG::Common::Apache::Session::Serialize::JSON::serialize;
         $self->{unserialize} =
           \&Lemonldap::NG::Common::Apache::Session::Serialize::JSON::unserialize;
+        if ( $backend =~ /^Apache::Session::LDAP/ ) {
+            $self->{unserialize} =
+              \&Lemonldap::NG::Common::Apache::Session::Serialize::JSON::unserializeBase64;
+        }
     }
     if ( $self->{args}->{generateModule} ) {
         my $generate = $self->{args}->{generateModule};
